@@ -3,13 +3,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI Utilities
 
-our $VERSION = '0.0601';
+our $VERSION = '0.0602';
 
 use strict;
 use warnings;
 
-use MIDI;
-use MIDI::Simple;
+use MIDI ();
+use MIDI::Simple ();
 use Music::Tempo;
 
 
@@ -179,7 +179,7 @@ MIDI::Util - MIDI Utilities
 
 =head1 VERSION
 
-version 0.0601
+version 0.0602
 
 =head1 SYNOPSIS
 
